@@ -1,11 +1,13 @@
-use Stenciller::Standard;
-
-our $VERSION = '0.1205'; # VERSION:
-# ABSTRACT: A plugin that transforms to html
-# PODCLASSNAME:
+use 5.14.0;
+use strict;
+use warnings;
 
 package Stenciller::Plugin::ToHtmlPreBlock;
+our $VERSION = '0.1206'; # VERSION:
+# ABSTRACT: A plugin that transforms to html
+
 use Moose;
+use List::AllUtils qw/first_index/;
 with 'Stenciller::Transformer';
 
 use HTML::Entities 'encode_entities';
@@ -19,7 +21,7 @@ sub transform {
 
     STENCIL:
     for my $i (0 .. $self->stenciller->count_stencils - 1) {
-        next STENCIL if exists $transform_args->{'stencils'} && first_index { $_ == $i } @{ $transform_args->{'stencils'} };
+        next STENCIL if exists $transform_args->{'stencils'} && -1 == first_index { $_ == $i } @{ $transform_args->{'stencils'} };
 
         my $stencil = $self->stenciller->get_stencil($i);
 
@@ -62,7 +64,7 @@ Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
 
 =head1 VERSION
 
-Version 0.1205, released 2015-01-18.
+Version 0.1206, released 2015-02-07.
 
 =head1 SYNOPSIS
 
